@@ -258,25 +258,13 @@ if (reference==TRUE) {
     extraArgs <- model.args[[f]]
     if (predictHandlerFun=="predictEventProb"){
       pred <- do.call(predictHandlerFun,c(list(object=fit,newdata=data,times=times,train.data=data,cause=cause),extraArgs))
+      if (class(object[[f]])[[1]]=="matrix") pred <- pred[neworder,]
       ## if (f==2) browser()
-      .C("pecCR",
-         pec=double(NT),
-         as.double(Y),
-         as.double(status),
-         as.double(event),
-         as.double(times),
-         as.double(pred),
-         as.double(ipcw$IPCW.times),
-         as.double(ipcw$IPCW.subjectTimes),
-         as.integer(N),
-         as.integer(NT),
-         as.integer(ipcw$dim),
-         as.integer(NCOL(pred)>1),
-         NAOK=TRUE,
-         PACKAGE="pec")$pec
+      .C("pecCR",pec=double(NT),as.double(Y),as.double(status),as.double(event),as.double(times),as.double(pred),as.double(ipcw$IPCW.times),as.double(ipcw$IPCW.subjectTimes),as.integer(N),as.integer(NT),as.integer(ipcw$dim),as.integer(NCOL(pred)>1),NAOK=TRUE,PACKAGE="pec")$pec
     }
     else{
       pred <- do.call(predictHandlerFun,c(list(object=fit,newdata=data,times=times,train.data=data),extraArgs))
+      if (class(object[[f]])[[1]]=="matrix") pred <- pred[neworder,]
       .C("pec",pec=double(NT),as.double(Y),as.double(status),as.double(times),as.double(pred),as.double(ipcw$IPCW.times),as.double(ipcw$IPCW.subjectTimes),as.integer(N),as.integer(NT),as.integer(ipcw$dim),as.integer(NCOL(pred)>1),NAOK=TRUE,PACKAGE="pec")$pec
     }
   })
